Scrapinghub command line client
===============================

``shub`` is the Scrapinghub command line client. It allows you to deploy
projects or dependencies, schedule spiders, and retrieve scraped data or logs
without leaving the command line.


Requirements
------------

* Python 2.7+ or Python 3.3+


Installation
------------

If you have ``pip`` installed on your system, you can install ``shub`` from
the Python Package Index::

    pip install shub

We also supply stand-alone binaries. You can find them in our `latest GitHub
release`_.

.. _`latest Github release`: https://github.com/scrapinghub/shub/releases/latest


Documentation
-------------

Documentation is available online via Read the Docs:
https://shub.readthedocs.io/, or in the ``docs`` directory.
